Appender

Struct Appender 

pub struct Appender { /* private fields */ }
A DuckDB appender for bulk-inserting rows into a table. A DuckDB appender for bulk-inserting rows into a table without going through the SQL parser.

Call append for each row and save to flush the data to the database. Rows are also flushed automatically on drop (errors during the implicit flush are logged to stderr).

Implementations

Source

impl Appender

pub fn new(con: RawConnection, table: &str, schema: &str) -> Result<Appender>

Creates a new Appender for the given table and schema.

Errors

Returns an error if the table does not exist or the DuckDB appender cannot be created.

pub fn append<T: AppendAble>(&mut self, row: &mut T) -> Result<()>

Appends a row to the table.

Calls duckdb_appender_begin_row, then the value appender, then duckdb_appender_end_row.

Errors

Returns an error if the row cannot be appended.

pub fn save(&mut self) -> Result<()>

Flushes all buffered rows to the database.

Errors

Returns an error if the flush fails.