pub struct Appender { /* private fields */ }Expand description
A DuckDB appender for bulk-inserting rows into a table. A DuckDB appender for bulk-inserting rows into a table without going through the SQL parser.
Call append for each row and save
to flush the data to the database. Rows are also flushed automatically on drop
(errors during the implicit flush are logged to stderr).
Implementations
Sourceimpl Appender
impl Appender
Sourcepub fn new(con: RawConnection, table: &str, schema: &str) -> Result<Appender>
pub fn new(con: RawConnection, table: &str, schema: &str) -> Result<Appender>
Creates a new Appender for the given table and schema.
Errors
Returns an error if the table does not exist or the DuckDB appender cannot be created.